@@ -320,7 +320,7 @@ def plot_KeplerianModel(my_data, my_model, res, saveloc='', options=None):
         temp_mod_names = []
         temp_dat_names = []
 
-        if switch_uncertain = options['uncertain']:
+        if switch_uncertain:
             import uncertainpy as un
             import chaospy as cp
             if logger_level is not None:
@@ -328,8 +328,6 @@ def plot_KeplerianModel(my_data, my_model, res, saveloc='', options=None):
                 logging.getLogger("numpoly").setLevel(logger_level)
 
 
-
-
     def create_mod(data_arg, blocks_arg, tail_x, mod_number=0):
         x = ReddModel(data_arg, blocks_arg)
         x.A_ = []
